@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2009-2021 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2009-2022 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -9,6 +9,9 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QDir>
+#include <QFileInfo>
+#include <QSettings>
 
 /**
  * Program entry point.
@@ -19,17 +22,6 @@
  */
 int main(int argc, char** argv)
 {
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-#if !defined(Q_OS_MAC)
-	if (!qEnvironmentVariableIsSet("QT_DEVICE_PIXEL_RATIO")
-			&& !qEnvironmentVariableIsSet("QT_AUTO_SCREEN_SCALE_FACTOR")
-			&& !qEnvironmentVariableIsSet("QT_SCALE_FACTOR")
-			&& !qEnvironmentVariableIsSet("QT_SCREEN_SCALE_FACTORS")) {
-		QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-	}
-#endif
-	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
 	QApplication app(argc, argv);
 	app.setApplicationName("Peg-E");
 	app.setApplicationVersion(VERSIONSTR);
@@ -42,24 +34,35 @@ int main(int argc, char** argv)
 #endif
 	app.setAttribute(Qt::AA_DontShowIconsInMenus, true);
 
-	LocaleDialog::loadTranslator("pege_");
+	// Find application data
+	const QString appdir = app.applicationDirPath();
+	const QString datadir = QDir::cleanPath(appdir + "/" + PEGE_DATADIR);
+
+	// Handle portability
+#ifdef Q_OS_MAC
+	const QFileInfo portable(appdir + "/../../../Data");
+#else
+	const QFileInfo portable(appdir + "/Data");
+#endif
+	if (portable.exists() && portable.isWritable()) {
+		QSettings::setDefaultFormat(QSettings::IniFormat);
+		QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, portable.absoluteFilePath() + "/Settings");
+	}
+
+	// Load application language
+	LocaleDialog::loadTranslator("pege_", datadir);
+
+	// Handle commandline
+	QCommandLineParser parser;
+	parser.setApplicationDescription(Window::tr("Peg elimination game"));
+	parser.addHelpOption();
+	parser.addVersionOption();
+	parser.process(app);
 
 	// Set location of fallback icons
-	{
-		QString appdir = app.applicationDirPath();
-		QString datadir;
-#if defined(Q_OS_MAC)
-		datadir = appdir + "/../Resources";
-#elif defined(Q_OS_UNIX)
-		datadir = appdir + "/../share/peg-e";
-#else
-		datadir = appdir;
-#endif
-
-		QStringList paths = QIcon::themeSearchPaths();
-		paths.prepend(datadir + "/icons");
-		QIcon::setThemeSearchPaths(paths);
-	}
+	QStringList paths = QIcon::themeSearchPaths();
+	paths.prepend(datadir + "/icons");
+	QIcon::setThemeSearchPaths(paths);
 
 	// Set up icons
 #if defined(Q_OS_MAC) || defined(Q_OS_WIN)
@@ -71,12 +74,7 @@ int main(int argc, char** argv)
 	QIcon::setFallbackThemeName("hicolor");
 #endif
 
-	QCommandLineParser parser;
-	parser.setApplicationDescription(Window::tr("Peg elimination game"));
-	parser.addHelpOption();
-	parser.addVersionOption();
-	parser.process(app);
-
+	// Create main window
 	Window window;
 	window.show();
 
