@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2013 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2013 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "movement.h"
 
@@ -27,11 +14,11 @@
 
 //-----------------------------------------------------------------------------
 
-Movement::Movement(const QPoint& start_hole, const QPoint& end_hole, Board* board) :
-	m_start_hole(start_hole),
-	m_jumped_hole(start_hole + ((end_hole - start_hole) / 2)),
-	m_end_hole(end_hole),
-	m_board(board)
+Movement::Movement(const QPoint& start_hole, const QPoint& end_hole, Board* board)
+	: m_start_hole(start_hole)
+	, m_jumped_hole(start_hole + ((end_hole - start_hole) / 2))
+	, m_end_hole(end_hole)
+	, m_board(board)
 {
 	Q_ASSERT(m_board->isPeg(m_start_hole));
 	Q_ASSERT(m_board->isPeg(m_jumped_hole));
@@ -45,8 +32,8 @@ Movement::Movement(const QPoint& start_hole, const QPoint& end_hole, Board* boar
 
 void Movement::redo()
 {
-	m_board->hole(m_start_hole)->setPeg(0);
-	m_board->hole(m_jumped_hole)->setPeg(0);
+	m_board->hole(m_start_hole)->setPeg(nullptr);
+	m_board->hole(m_jumped_hole)->setPeg(nullptr);
 	m_board->hole(m_end_hole)->setPeg(m_peg);
 
 	m_jumped_peg->hide();
@@ -63,7 +50,7 @@ void Movement::undo()
 {
 	m_board->hole(m_start_hole)->setPeg(m_peg);
 	m_board->hole(m_jumped_hole)->setPeg(m_jumped_peg);
-	m_board->hole(m_end_hole)->setPeg(0);
+	m_board->hole(m_end_hole)->setPeg(nullptr);
 
 	m_peg->move(m_start_hole);
 	m_jumped_peg->show();
