@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2013, 2014 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2014 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef PEGE_PUZZLE_H
 #define PEGE_PUZZLE_H
@@ -37,7 +24,7 @@ class Puzzle
 {
 public:
 	/** Constructs an empty layout. */
-	Puzzle();
+	explicit Puzzle();
 
 	/** Destroys the layout. */
 	virtual ~Puzzle();
@@ -133,7 +120,7 @@ protected:
 	 *
 	 * @param pegs how many pegs to create
 	 */
-	void generate(int pegs);
+	void generate(int pegs) override;
 };
 
 /** Puzzle that doesn't reuse or shuffle any holes. */
@@ -145,14 +132,14 @@ protected:
 	 *
 	 * @param hole the hole to check
 	 */
-	bool isAvailable(const QPoint& hole) const;
+	bool isAvailable(const QPoint& hole) const override;
 
 	/**
 	 * Override parent function to prevent shuffling the pegs.
 	 *
 	 * @param pegs the pegs to shuffle
 	 */
-	void shuffle(QList<QPoint>& pegs);
+	void shuffle(QList<QPoint>& pegs) override;
 };
 
 #endif // PEGE_PUZZLE_H
